Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(237)

Unified Diff: src/gpu/GrDrawState.h

Issue 15821008: Make GrContext track the current matrix, render target, and clip directly rather than using GrDrawS… (Closed) Base URL: https://skia.googlecode.com/svn/trunk
Patch Set: put back wideopen check Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/gpu/GrDrawState.h
diff --git a/src/gpu/GrDrawState.h b/src/gpu/GrDrawState.h
index 80ad28eac5d794edafa6915fb425a2ed5bee4ca4..bf3ef74e9411ca6c088889c5db904e54116c958e 100644
--- a/src/gpu/GrDrawState.h
+++ b/src/gpu/GrDrawState.h
@@ -95,12 +95,12 @@ public:
}
/**
* Initializes the GrDrawState based on a GrPaint. Note that GrDrawState
* encompasses more than GrPaint. Aspects of GrDrawState that have no
* GrPaint equivalents are not modified. GrPaint has fewer stages than
* GrDrawState. The extra GrDrawState stages are disabled.
*/
- void setFromPaint(const GrPaint& paint);
+ void setFromPaint(const GrPaint& , const SkMatrix& viewMatrix, GrRenderTarget*);
///////////////////////////////////////////////////////////////////////////
/// @name Vertex Attributes
« src/gpu/GrContext.cpp ('K') | « src/gpu/GrContext.cpp ('k') | src/gpu/GrDrawState.cpp » ('j') | no next file with comments »
@@ -95,12 +95,12 @@ public:
}
/**
- * Initializes the GrDrawState based on a GrPaint. Note that GrDrawState
- * encompasses more than GrPaint. Aspects of GrDrawState that have no
- * GrPaint equivalents are not modified. GrPaint has fewer stages than
- * GrDrawState. The extra GrDrawState stages are disabled.
+ * Initializes the GrDrawState based on a GrPaint, view matrix and render target. Note that
+ * GrDrawState encompasses more than GrPaint. Aspects of GrDrawState that have no GrPaint
+ * equivalents are set to default values. GrPaint has fewer stages than GrDrawState. The extra
+ * GrDrawState stages are disabled.
*/

Powered by Google App Engine
This is Rietveld 408576698